@@ -18,12 +18,13 @@ package PkgConfig::UDefs;
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.06120';
+our $VERSION = '0.06420';
 
-require 5.005;
+require 5.006;
 
 use strict;
 use warnings;
+use Config;
 use File::Spec;
 use Class::Struct; #in core since 5.004
 our $UseDebugging;
@@ -63,7 +64,7 @@ our @DEFAULT_SEARCH_PATH = qw(
 
 );
 
-my @ENV_SEARCH_PATH = split(/:/, $ENV{PKG_CONFIG_PATH} || "");
+my @ENV_SEARCH_PATH = split($Config{path_sep}, $ENV{PKG_CONFIG_PATH} || "");
 
 push @DEFAULT_SEARCH_PATH, @ENV_SEARCH_PATH;
 
@@ -226,7 +227,10 @@ sub assign_var {
                     $self->_get_pc_varname($field), $value);
     
     log_debug("EVAL", $evalstr);
-    eval $evalstr;
+    do {
+        no warnings 'uninitialized';
+        eval $evalstr;
+    };
     if($@) {
         log_err($@);
     }
@@ -408,12 +412,11 @@ sub parse_line {
 
     log_debugf("Field %s, Value %s", $field, $value);
     
+    $field = lc($field);
+    
     #perl variables can't have '.' in them:
     $field =~ s/\./DOT/g;
     
-    
-    $field = lc($field);
-    
     #remove quoutes from field names
     $field =~ s/['"]//g;
     
@@ -698,7 +701,10 @@ GetOptions(
     'static' => \my $UseStatic,
     'cflags' => \my $PrintCflags,
     'exists' => \my $PrintExists,
-    
+    'atleast-version=s' => \my $AtLeastVersion,
+    'exact-version=s'   => \my $ExactVersion,
+    'max-version=s'     => \my $MaxVersion,
+
     'silence-errors' => \my $SilenceErrors,
     'print-errors' => \my $PrintErrors,
     
@@ -764,7 +770,7 @@ if($WantFlags) {
 }
 
 my %pc_options;
-if($PrintExists) {
+if($PrintExists || $AtLeastVersion || $ExactVersion || $MaxVersion) {
     $pc_options{no_recurse} = 1;
 }
 
@@ -789,6 +795,31 @@ if($o->errmsg) {
     exit(1);
 }
 
+if($ExactVersion) {
+    exit(2) unless $o->pkg_version eq $ExactVersion;
+}
+
+sub _is_greater_than_or_equal ($$)
+{
+    my @a = split /\./, shift;
+    my @b = split /\./, shift;
+    while(@a || @b) {
+        my $a = shift(@a) || 0;
+        my $b = shift(@b) || 0;
+        return 1 if $a > $b;
+        return 0 if $a < $b;
+    }
+    return 1;
+}
+
+if($AtLeastVersion) {
+    exit(2) unless _is_greater_than_or_equal($o->pkg_version, $AtLeastVersion);
+}
+
+if($MaxVersion) {
+    exit(2) unless _is_greater_than_or_equal($MaxVersion, $o->pkg_version);
+}
+
 if($o->print_variables) {
     while (my ($k,$v) = each %{$o->defined_variables}) {
         print $k;
